@@ -70,13 +70,22 @@ bonobo_plug_finalize (GObject *object)
   }
 }
 
+static gint
+bonobo_plug_get_index_in_parent (AtkObject *obj)
+{
+  return 0;
+}
+
 static void
 bonobo_plug_atk_object_class_init (BonoboPlugAtkObjectClass *klass)
 {
   GObjectClass *gobject_class = (GObjectClass *) klass;
+  AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
 
   gobject_class->finalize = bonobo_plug_finalize;
 
+  class->get_index_in_parent = bonobo_plug_get_index_in_parent;
+
   quark_private_control = g_quark_from_static_string ("gail-gnome-private-control");
 }
 
@@ -85,7 +94,7 @@ bonobo_plug_atk_object_init  (BonoboPlugAtkObject        *accessible,
 			      BonoboPlugAtkObjectClass   *klass)
 {
 	g_assert (ATK_IS_OBJECT (accessible));
-	ATK_OBJECT (accessible)->role = ATK_ROLE_WINDOW;
+	ATK_OBJECT (accessible)->role = ATK_ROLE_EMBEDDED;
 }
 
 static void
@@ -99,9 +108,9 @@ bonobo_plug_atk_object_get_type (void)
 {
   static GType type = 0;
 
-  if (!type)
+  if (G_UNLIKELY (type == 0))
     {
-      static GTypeInfo typeInfo =
+      GTypeInfo typeInfo =
       {
         0,
         (GBaseInitFunc) NULL,
@@ -112,7 +121,7 @@ bonobo_plug_atk_object_get_type (void)
         (GInstanceInitFunc) bonobo_plug_atk_object_init,
       };
 
-      static const GInterfaceInfo remote_info =
+      const GInterfaceInfo remote_info =
       {
 	(GInterfaceInitFunc) bonobo_plug_atk_object_remote_init,
 	NULL,
@@ -123,7 +132,7 @@ bonobo_plug_atk_object_get_type (void)
       GType             derived_type;
       GTypeQuery        query;
 
-      factory = atk_registry_get_factory (atk_get_default_registry (), GTK_TYPE_CONTAINER);
+      factory = atk_registry_get_factory (atk_get_default_registry (), GTK_TYPE_PLUG);
       derived_type = atk_object_factory_get_accessible_type (factory);
       g_type_query (derived_type, &query);
 
