@@ -117,9 +117,9 @@ bonobo_socket_atk_object_get_type (void)
 {
   static GType type = 0;
 
-  if (!type)
+  if (G_UNLIKELY (!type))
     {
-      static GTypeInfo typeInfo =
+      GTypeInfo typeInfo =
       {
         0,
         (GBaseInitFunc) NULL,
@@ -130,7 +130,7 @@ bonobo_socket_atk_object_get_type (void)
         (GInstanceInitFunc) bonobo_socket_atk_object_init,
       };
 
-      static const GInterfaceInfo remote_info =
+      const GInterfaceInfo remote_info =
       {
 	(GInterfaceInitFunc) bonobo_socket_atk_object_remote_init,
 	NULL,
